﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using MindFusion.Diagramming.Wpf.Lanes;
using MindFusion.Diagramming.Wpf;

namespace WpfApplication22
{
	/// <summary>
	/// Interaction logic for Window1.xaml
	/// </summary>
	public partial class Window1 : Window
	{
		public Window1()
		{
			InitializeComponent();

			MindFusion.Diagramming.Wpf.Lanes.Grid g = diagram1.LaneGrid;

			g.ColumnHeadersHeights = new double[] { 100 };
			g.RowHeadersWidths = new double[] { 100 };

			diagram1.EnableLanes = true;
			g.RowCount = 10;
			g.ColumnCount = 10;

			diagram1.AllowUnconnectedLinks = true;

			diagram1.MouseMove += new MouseEventHandler(diagram1_MouseMove);
			diagram1.Clicked += new DiagramEventHandler(diagram1_Clicked);
		}

		private void diagram1_Clicked(object sender, MindFusion.Diagramming.Wpf.DiagramEventArgs e)
		{
			Rect cellBounds = Rect.Empty;
			ICell clickedCell = diagram1.LaneGrid.GetCellFromPoint(e.MousePosition, ref cellBounds);

			if (clickedCell != null)
			{
				MindFusion.Diagramming.Wpf.Lanes.Grid g = diagram1.LaneGrid;

				cellBounds.Inflate(-5, -5);
				ShapeNode shape = diagram1.Factory.CreateShapeNode(cellBounds);

				int row = g.GetCellRow(clickedCell);
				int column = g.GetCellColumn(clickedCell);

				Rect columnBounds = g.GetHeaderBounds(g.ColumnHeaders[column], false);
				Rect rowBounds = g.GetHeaderBounds(g.RowHeaders[row], false);

				diagram1.Factory.CreateDiagramLink(shape, new Point(rowBounds.Right, rowBounds.Y + rowBounds.Height / 2));
				diagram1.Factory.CreateDiagramLink(shape, new Point(columnBounds.X + columnBounds.Width / 2, columnBounds.Bottom));
			}
		}

		private void diagram1_MouseMove(object sender, MouseEventArgs e)
		{
			Point client = e.GetPosition(diagram1);
			Point doc = diagram1.ClientToDoc(client);

			Rect cellBounds = Rect.Empty;
			ICell newPointedCell = diagram1.LaneGrid.GetCellFromPoint(doc, ref cellBounds);

			if (lastPointedCell != newPointedCell)
			{
				ResetProjections(lastPointedCell);
				lastPointedCell = newPointedCell;
				SetProjections(newPointedCell);
			}
		}

		private void ResetProjections(ICell cell)
		{
			int row = diagram1.LaneGrid.GetCellRow(lastPointedCell);
			int column = diagram1.LaneGrid.GetCellColumn(lastPointedCell);

			for (int i = 0; i <= row; i++)
				diagram1.LaneGrid[column, i].Style.BackgroundBrush = Brushes.White;
			for (int j = 0; j < column; j++)
				diagram1.LaneGrid[j, row].Style.BackgroundBrush = Brushes.White;
		}

		private void SetProjections(ICell cell)
		{
			int row = diagram1.LaneGrid.GetCellRow(lastPointedCell);
			int column = diagram1.LaneGrid.GetCellColumn(lastPointedCell);

			for (int i = 0; i <= row; i++)
				diagram1.LaneGrid[column, i].Style.BackgroundBrush = Brushes.Lime;
			for (int j = 0; j < column; j++)
				diagram1.LaneGrid[j, row].Style.BackgroundBrush = Brushes.Lime;
		}


		private ICell lastPointedCell;
	}
}
